@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.4.17
+VERSION=4.4.19.1
 
 usage() # $1 = exit status
 {
@@ -123,6 +123,7 @@ done
 
 PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin:/usr/local/sbin
 
+[ -n "${LIBEXEC:=share}" ]
 #
 # Determine where to install the firewall script
 #
@@ -187,6 +188,7 @@ else
     rm -rf ${DESTDIR}/etc/shorewall6-lite
     rm -rf ${DESTDIR}/usr/share/shorewall6-lite
     rm -rf ${DESTDIR}/var/lib/shorewall6-lite
+    [ "$LIBEXEC" = share ] || rm -rf /usr/share/shorewall6-lite/wait4ifup /usr/share/shorewall6-lite/shorecap
 fi
 
 #
@@ -202,6 +204,8 @@ delete_file ${DESTDIR}/usr/share/shorewall6-lite/xmodules
 
 install_file shorewall6-lite ${DESTDIR}/sbin/shorewall6-lite 0544
 
+eval sed -i \'``s\|g_libexec=.\*\|g_libexec=$LIBEXEC\|\' ${DESTDIR}/sbin/shorewall6-lite
+
 echo "Shorewall6 Lite control program installed in ${DESTDIR}/sbin/shorewall6-lite"
 
 #
@@ -223,6 +227,7 @@ echo  "Shorewall6 Lite script installed in ${DESTDIR}${DEST}/$INIT"
 #
 mkdir -p ${DESTDIR}/etc/shorewall6-lite
 mkdir -p ${DESTDIR}/usr/share/shorewall6-lite
+mkdir -p ${DESTDIR}/usr/${LIBEXEC}/shorewall6-lite
 mkdir -p ${DESTDIR}/var/lib/shorewall6-lite
 
 chmod 755 ${DESTDIR}/etc/shorewall6-lite
@@ -275,30 +280,41 @@ echo "Common functions linked through ${DESTDIR}/usr/share/shorewall6-lite/funct
 # Install Shorecap
 #
 
-install_file shorecap ${DESTDIR}/usr/share/shorewall6-lite/shorecap 0755
+install_file shorecap ${DESTDIR}/usr/${LIBEXEC}/shorewall6-lite/shorecap 0755
 
 echo
-echo "Capability file builder installed in ${DESTDIR}/usr/share/shorewall6-lite/shorecap"
+echo "Capability file builder installed in ${DESTDIR}/usr/${LIBEXEC}/shorewall6-lite/shorecap"
 
 #
 # Install wait4ifup
 #
 
 if [ -f wait4ifup ]; then
-    install_file wait4ifup ${DESTDIR}/usr/share/shorewall6-lite/wait4ifup 0755
+    install_file wait4ifup ${DESTDIR}/usr/${LIBEXEC}/shorewall6-lite/wait4ifup 0755
 
     echo
-    echo "wait4ifup installed in ${DESTDIR}/usr/share/shorewall6-lite/wait4ifup"
+    echo "wait4ifup installed in ${DESTDIR}/usr/${LIBEXEC}/shorewall6-lite/wait4ifup"
 fi
 
+#
+# Install the Modules files
+#
+
 if [ -f modules ]; then
-    #
-    # Install the Modules file
-    #
     run_install $OWNERSHIP -m 0600 modules ${DESTDIR}/usr/share/shorewall6-lite
     echo "Modules file installed as ${DESTDIR}/usr/share/shorewall6-lite/modules"
 fi
 
+if [ -f helpers ]; then
+    run_install $OWNERSHIP -m 0600 helpers ${DESTDIR}/usr/share/shorewall6-lite
+    echo "Helper modules file installed as ${DESTDIR}/usr/share/shorewall6-lite/modules"
+fi
+
+for f in modules.*; do
+    run_install $OWNERSHIP -m 0644 $f ${DESTDIR}/usr/share/shorewall6-lite/$f
+    echo "Modules file $f installed as ${DESTDIR}/usr/share/shorewall6-lite/$f"
+done
+
 if [ -d manpages ]; then
     #
     # Install the Man Pages
